==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datalakestore/kotlin/inputs/CreateFirewallRuleWithAccountParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakestore.kotlin.inputs

import com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters used to create a new firewall rule while creating a new Data Lake Store account.
 * @property endIpAddress The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
 * @property name The unique name of the firewall rule to create.
 * @property startIpAddress The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
 */
public data class CreateFirewallRuleWithAccountParametersArgs(
    public val endIpAddress: Output<String>,
    public val name: Output<String>,
    public val startIpAddress: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs =
        com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs.builder()
            .endIpAddress(endIpAddress.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .startIpAddress(startIpAddress.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CreateFirewallRuleWithAccountParametersArgs].
 */
@PulumiTagMarker
public class CreateFirewallRuleWithAccountParametersArgsBuilder internal constructor() {
    private var endIpAddress: Output<String>? = null

    private var name: Output<String>? = null

    private var startIpAddress: Output<String>? = null

    /**
     * @param value The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("eddcxufwnbhijvsp")
    public suspend fun endIpAddress(`value`: Output<String>) {
        this.endIpAddress = value
    }

    /**
     * @param value The unique name of the firewall rule to create.
     */
    @JvmName("eafmmjdnumytexvb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("ouqdephnbduorggw")
    public suspend fun startIpAddress(`value`: Output<String>) {
        this.startIpAddress = value
    }

    /**
     * @param value The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("ocxcfgtotivitewv")
    public suspend fun endIpAddress(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endIpAddress = mapped
    }

    /**
     * @param value The unique name of the firewall rule to create.
     */
    @JvmName("xqisnkxpirlqudxc")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("unhowelyptdypkeq")
    public suspend fun startIpAddress(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startIpAddress = mapped
    }

    internal fun build(): CreateFirewallRuleWithAccountParametersArgs =
        CreateFirewallRuleWithAccountParametersArgs(
            endIpAddress = endIpAddress ?: throw PulumiNullFieldException("endIpAddress"),
            name = name ?: throw PulumiNullFieldException("name"),
            startIpAddress = startIpAddress ?: throw PulumiNullFieldException("startIpAddress"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datalakestore/kotlin/inputs/CreateFirewallRuleWithAccountParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakestore.kotlin.inputs

import com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters used to create a new firewall rule while creating a new Data Lake Store account.
 * @property endIpAddress The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
 * @property name The unique name of the firewall rule to create.
 * @property startIpAddress The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
 */
public data class CreateFirewallRuleWithAccountParametersArgs(
    public val endIpAddress: Output<String>,
    public val name: Output<String>,
    public val startIpAddress: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs =
        com.pulumi.azurenative.datalakestore.inputs.CreateFirewallRuleWithAccountParametersArgs.builder()
            .endIpAddress(endIpAddress.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .startIpAddress(startIpAddress.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CreateFirewallRuleWithAccountParametersArgs].
 */
@PulumiTagMarker
public class CreateFirewallRuleWithAccountParametersArgsBuilder internal constructor() {
    private var endIpAddress: Output<String>? = null

    private var name: Output<String>? = null

    private var startIpAddress: Output<String>? = null

    /**
     * @param value The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("csywhijtgpktofcl")
    public suspend fun endIpAddress(`value`: Output<String>) {
        this.endIpAddress = value
    }

    /**
     * @param value The unique name of the firewall rule to create.
     */
    @JvmName("sedbcrxoteokloii")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("smbfmmrnhysvxgvv")
    public suspend fun startIpAddress(`value`: Output<String>) {
        this.startIpAddress = value
    }

    /**
     * @param value The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("jpxbsyhkokxkiegr")
    public suspend fun endIpAddress(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endIpAddress = mapped
    }

    /**
     * @param value The unique name of the firewall rule to create.
     */
    @JvmName("hvtppxyqocrnfdcm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
     */
    @JvmName("mqpvebadhhxhlhbc")
    public suspend fun startIpAddress(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startIpAddress = mapped
    }

    internal fun build(): CreateFirewallRuleWithAccountParametersArgs =
        CreateFirewallRuleWithAccountParametersArgs(
            endIpAddress = endIpAddress ?: throw PulumiNullFieldException("endIpAddress"),
            name = name ?: throw PulumiNullFieldException("name"),
            startIpAddress = startIpAddress ?: throw PulumiNullFieldException("startIpAddress"),
        )
}
